@@ -4,6 +4,7 @@ Vue.component('errors-table', {
   <thead>
     <tr>
       <th>Filename</th>
+      <th>Dataset</th>
       <th>Owner</th>
       <th>Size</th>
       <th>Reason</th>
@@ -16,12 +17,23 @@ Vue.component('errors-table', {
       <span class="subtitle">&lt;root&gt;/</span><span><strong>{{ getFilePath(upload, root_path) }}</strong></span>
       <div><span class="subtitle">Obs Date:</span> {{ upload.file_date }}</div>
     </td>
+    <td>
+      <div v-if="upload.dataset">
+        <a v-if="upload.organisation" :href='getOrganisationDatasetURL(upload)' target="_blank">
+          {{ upload.dataset.name }}
+        </a>
+        <a v-else :href='getDatasetURL(upload)' target="_blank">
+          {{ upload.dataset.name }}
+        </a>
+        <div class="subtitle">{{ upload.dataset.uuid }}</div>
+      </div>
+    </td>    
     <td>
       <a v-if="upload.organisation" :href='getOrganisationURL(upload)' target="_blank">{{ upload.organisation.subdomain }}</a>
       <a v-else-if="upload.astronomer" :href='getProfileURL(upload)' target="_blank">@{{ upload.astronomer }}</a>
     </td>
     <td>
-      {{ getFormattedSize(upload.file_size) }}
+      {{ getFormattedSize(upload.file_size || upload.file_size_zipped) }}
     </td>
     <td>
       {{ upload.error }}
