@@ -42,7 +42,8 @@ def get_oort_db_file_path() -> Path:
 
 
 def get_oort_supervisor_conf_file_path() -> Path:
-    return _get_directory_path() / 'supervisord.conf'
+    suffix = '-tests' if os.environ.get('OORT_TESTS') == '1' else ''
+    return _get_directory_path() / f'supervisord{suffix}.conf'
 
 
 def get_oort_logger(process_name, debug=False) -> Logger:
@@ -53,10 +54,11 @@ def get_oort_logger(process_name, debug=False) -> Logger:
     if len(logger.handlers) == 0:
         formatter = Formatter('%(asctime)s - %(name)s[' + process_name + '] - %(levelname)s - %(message)s')
 
-        file_handler = FileHandler(str(get_oort_log_file_path()))
-        file_handler.setLevel(DEBUG if debug else INFO)
-        file_handler.setFormatter(formatter)
-        logger.addHandler(file_handler)
+        if os.environ.get('OORT_TESTS') != '1':
+            file_handler = FileHandler(str(get_oort_log_file_path()))
+            file_handler.setLevel(DEBUG if debug else INFO)
+            file_handler.setFormatter(formatter)
+            logger.addHandler(file_handler)
 
         console_handler = StreamHandler()
         console_handler.setLevel(DEBUG if debug else INFO)
