@@ -1,5 +1,4 @@
 import atexit
-import math
 import pathlib
 from datetime import datetime
 from enum import Enum
@@ -19,8 +18,9 @@ from playhouse.sqliteq import SqliteQueueDatabase
 
 from oort.shared.config import get_oort_db_file_path
 from oort.shared.constants import ZIP_EXTENSIONS
-
 # Create global instance 'db'
+from oort.shared.utils import get_formatted_bytes_size
+
 db = SqliteQueueDatabase(str(get_oort_db_file_path()),
                          use_gevent=False,
                          autostart=True,
@@ -41,7 +41,7 @@ class BaseModel(Model):
 
     _primary_field = 'uuid'
 
-    def smart_update(self, **kwargs):
+    def smart_update(self, **kwargs) -> None:
         for k, v in kwargs.items():
             if k in self.__class__._meta.sorted_field_names:
                 setattr(self, k, v)
@@ -126,7 +126,6 @@ FINISHED_SUBSTATUSES = [Substatus.DONE.value,
 
 PREPARATION_DONE_SUBSTATUSES = [Substatus.CHECKING.value,
                                 Substatus.READY.value,
-                                Substatus.RESTART.value,
                                 Substatus.STARTING.value,
                                 Substatus.UPLOADING.value] + FINISHED_SUBSTATUSES
 
@@ -173,29 +172,24 @@ class Upload(BaseModel):
 
     def get_formatted_size(self) -> str:
         size = self.file_size or self.file_size_zipped or 0
-        if size == 0:
-            return '0 Bytes'
-        k = 1024
-        units = ['Bytes', 'kB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB']
-        i = math.floor(math.log10(1.0 * size) / math.log10(k))
-        return f"{(size / math.pow(k, i)):.2f} {units[i]}"
+        return get_formatted_bytes_size(size)
 
-    def archive(self, substatus):
-        return self.smart_update(status=Status.OK.value, substatus=substatus, ended=datetime.now())
+    def archive(self, substatus) -> None:
+        self.smart_update(status=Status.OK.value, substatus=substatus, ended=datetime.now())
 
-    def reset_for_restart(self):
-        return self.smart_update(status=Status.NEW.value,
-                                 substatus=Substatus.RESTART.value,
-                                 progress=0,
-                                 started=None,
-                                 ended=None,
-                                 duration=0,
-                                 error='',
-                                 dataset=None,
-                                 file_date=None,
-                                 file_size=0,
-                                 file_size_zipped=0,
-                                 target_name='')
+    def reset_for_restart(self) -> None:
+        self.smart_update(status=Status.NEW.value,
+                          substatus=Substatus.RESTART.value,
+                          progress=0,
+                          started=None,
+                          ended=None,
+                          duration=0,
+                          error='',
+                          dataset=None,
+                          file_date=None,
+                          file_size=0,
+                          file_size_zipped=0,
+                          target_name='')
 
 
 db.connect(reuse_if_open=True)
