@@ -2,6 +2,7 @@ import bz2
 import gzip
 import os
 import pathlib
+import subprocess
 import warnings
 import xml.etree.ElementTree as ET
 from datetime import datetime, timedelta
@@ -75,20 +76,15 @@ class UploadPack(object):
         except Upload.DoesNotExist:
             self._upload = Upload.create(file_path=self.clear_file_path)
 
+    def collect_file_info(self):
+        self._logger.info(f'{self.log_prefix} {self.final_file_name} Collecting info...')
         if self._force:
             self._upload.reset_for_restart()
-
-        self.upload.smart_update(astronomer=self._identity.username,
-                                 file_path_zipped=self.zipped_file_path)
-
+        self.upload.smart_update(astronomer=self._identity.username, file_path_zipped=self.zipped_file_path)
         self._find_date_size_and_target_name()
 
     def prepare_and_upload_file(self, display_progress: bool = False):
-        if self.should_zip:
-            zip = zipper.AsyncZipper(self.clear_file_path)
-            zip.start()
-
-        elif self.is_hidden_file:
+        if self.is_hidden_file:
             self._logger.info(f'{self.log_prefix} {self.final_file_name} is an hidden file. Upload skipped.')
             self._archive(Substatus.SKIPPED_HIDDEN_FILE.value)
 
@@ -98,13 +94,25 @@ class UploadPack(object):
 
         else:
             item = f"{self.final_file_name} ({self._upload.substatus})"
-            preparation_succeeded = self._upload.dataset is not None
 
-            if self.should_prepare:
+            if self.should_zip:
+                if self.zipped_file_exists and not self._is_file_correctly_zipped(self.zipped_file_path):
+                    self._suppress_corrupted_zipped_file(self.zipped_file_path)
+
+                # Yes, using AsyncZipper in a non-asynchronous manner for now...
+                zip = zipper.AsyncZipper(self.clear_file_path)
+                zip.start()
+                zip.join(300)
+                if zip.is_alive():
+                    self._logger.info(f'{self.log_prefix} Zipped timeout for {item}.')
+                    return self._upload.status, self._upload.substatus, self._upload.error
+
+            if self.is_already_prepared:
+                self._logger.info(f'{self.log_prefix} Preparation already done for {item}.')
+                preparation_succeeded = True
+            else:
                 upload_preparator = preparator.UploadPreparator(self, debug=self._identity.debug)
                 preparation_succeeded = upload_preparator.prepare()
-            else:
-                self._logger.info(f'{self.log_prefix} Preparation already done for {item}.')
 
             if preparation_succeeded:
                 if self.is_already_finished:
@@ -132,9 +140,7 @@ class UploadPack(object):
         return self.identity.zip and \
                self.is_data_file and \
                self.clear_file_exists and \
-               not self.zipped_file_exists and \
-               self._upload.substatus != Substatus.ZIPPING.value and \
-               os.access(str(self._root_path), os.W_OK)
+               os.access(str(self._root_path), os.W_OK)  # checking the folder is writable
 
     @property
     def final_file_path(self):
@@ -179,7 +185,7 @@ class UploadPack(object):
 
     @property
     def is_empty_file(self):
-        return self._upload.file_size == 0 and self._upload.file_size_zipped == 0
+        return self._find_sizes() == (0, 0)
 
     @property
     def night_log_date_string(self) -> str:
@@ -217,8 +223,8 @@ class UploadPack(object):
         return self._upload.target_name.strip()
 
     @property
-    def should_prepare(self) -> bool:
-        return self._upload.substatus not in PREPARATION_DONE_SUBSTATUSES or self._upload.dataset is None
+    def is_already_prepared(self) -> bool:
+        return self._upload.substatus in PREPARATION_DONE_SUBSTATUSES or self._upload.dataset is not None
 
     @property
     def is_already_finished(self) -> bool:
@@ -352,4 +358,10 @@ class UploadPack(object):
         return target_name
 
     def _archive(self, substatus) -> None:
-        self._upload = self._upload.archive(substatus=substatus, ended=datetime.now())
+        self._upload.archive(substatus=substatus, ended=datetime.now())
+
+    def _is_file_correctly_zipped(self, file_path_gz):
+        return subprocess.check_output(['gzip', '-t', file_path_gz]) == b''
+
+    def _suppress_corrupted_zipped_file(self, file_path_gz):
+        return pathlib.Path(file_path_gz).unlink()
